package org.sakaiproject.template.facade;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.sakaiproject.content.api.ContentEntity;
import org.sakaiproject.content.api.ContentHostingHandlerResolver;
import org.sakaiproject.content.api.ContentHostingService;
import org.sakaiproject.content.api.ContentResource;
import org.sakaiproject.content.api.ContentResourceEdit;
import org.sakaiproject.entity.api.ResourceProperties;
import org.sakaiproject.entity.api.ResourcePropertiesEdit;
import org.sakaiproject.template.chh.TemplateCHH;
import org.sakaiproject.tool.api.ToolManager;
import org.sakaiproject.user.api.User;
import org.sakaiproject.user.api.UserDirectoryService;

public class TemplateFacadeImpl implements TemplateFacade {

	private static Log log = LogFactory.getLog(TemplateFacadeImpl.class);
	
	// Dependency injected lookup methods
	protected UserDirectoryService userDirectoryService() { return null; }
	protected ContentHostingService contentService() { return null; }
	protected ToolManager toolManager() { return null; }
	
	public String getUserName() {
		User user = userDirectoryService().getCurrentUser();
		return user.getDisplayName();
	}

	
	public String createResource(File resource) throws Exception {
		byte[] content = getFileAsBytes(resource);

		String siteId = toolManager().getCurrentPlacement().getContext();
		String siteCollectionId = contentService().getSiteCollection(siteId);
		String resourceId = new StringBuilder().append(siteCollectionId)
			.append(resource.getName()).toString();
		
		ContentResourceEdit edit = null;
		try {
			edit = contentService().addResource(resourceId);
			edit.setContentHandler(new TemplateCHH());
			edit.setContent(content);
			edit.setContentLength(content.length);
			edit.setContentType("application/zip");
			edit.setResourceType("org.sakaiproject.content.types.scormContentPackage");
	        
			ResourcePropertiesEdit props = edit.getPropertiesEdit();
			props.addProperty(ResourceProperties.PROP_DISPLAY_NAME, resource.getName());
			props.addProperty(ContentHostingHandlerResolver.CHH_BEAN_NAME, "org.sakaiproject.template.chh.TemplateCHH");
	        
			contentService().commitResource(edit);
		} catch (Exception e) {
			if (edit != null)
				contentService().cancelResource(edit);
			throw e;
		}
		
		return resourceId;
	}
	
	
	public ContentResource findResource(String resourceId) throws Exception {
		return contentService().getResource(resourceId);
	}
	
	
	private byte[] getFileAsBytes(File file) {
		int len = 0;
		byte[] buf = new byte[1024];
		ByteArrayOutputStream byteOut = new ByteArrayOutputStream();
		
		try {
			FileInputStream fileIn = new FileInputStream(file);
			while ((len = fileIn.read(buf)) > 0) {
				byteOut.write(buf,0,len);
			}
			
			fileIn.close();
		} catch (IOException ioe) {
			log.error("Caught an io exception trying to write file into byte array!", ioe);
		}
		
		return byteOut.toByteArray();
	}
	
}
