package org.sakaiproject.template.wicket.pages;

import java.io.File;
import java.io.IOException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.wicket.ajax.AjaxRequestTarget;
import org.apache.wicket.ajax.markup.html.AjaxLink;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.model.PropertyModel;
import org.apache.wicket.spring.injection.annot.SpringBean;
import org.sakaiproject.content.api.ContentHostingHandler;
import org.sakaiproject.content.api.ContentResource;
import org.sakaiproject.template.facade.TemplateFacade;
import org.sakaiproject.wicket.markup.html.SakaiPortletWebPage;

public class TemplateHomePage extends SakaiPortletWebPage {
	private static final long serialVersionUID = 1L;
	
	private static Log log = LogFactory.getLog(TemplateHomePage.class);
	
	@SpringBean
	TemplateFacade facade;
	
	private String resourceInfo;
	
	public TemplateHomePage() {
		add(new Label("name", facade.getUserName()));
		
		final Label resourceInfoLabel = new Label("resourceInfo", new PropertyModel(this, "resourceInfo"));
		resourceInfoLabel.setOutputMarkupId(true);
		
		add(new AjaxLink("add") {

			@Override
			public void onClick(AjaxRequestTarget target) {
				
				File tempFile;
				try {
					tempFile = File.createTempFile("xyz", ".txt");
					
					String id = facade.createResource(tempFile);
					
					StringBuilder builder = new StringBuilder().append("Created a new resource with a content hosting handler . . . ");
					
					ContentResource resource = facade.findResource(id);
					
					ContentHostingHandler chh = resource.getContentHandler();
					
					if (chh == null) 
						builder.append(" But now, the content hosting handler seems to be null!");
					else
						builder.append(" And it saved the content hosting handler correctly...");
					
					setResourceInfo(builder.toString());

					target.addComponent(resourceInfoLabel);
					
				} catch (Exception e) {
					log.error("Caught an exception adding a resource ", e);
				}				
			}
			
		});
		
		add(resourceInfoLabel);
	}
	

	public String getResourceInfo() {
		return resourceInfo;
	}

	public void setResourceInfo(String resourceInfo) {
		this.resourceInfo = resourceInfo;
	}
	
}
